@@ -139,8 +139,14 @@ class WebSocketRouter:
     # Ruse the Starlette Route framework
     # ... Discarded as having too much irrelevant code that would confuse functionality
 
+    # The default endpoint class created by this class
+    # ... This can be easily overridden via a subclass to change the default behavior.
     DEFAULT_ENDPOINT = WebSocketRouterEndpoint
 
+    # The JavaScript static files path for use in Starlette Mount commands
+    JS_PATH = Path(__file__).parent/'static'
+
+
     def __init__(self, routes: list[WebSocketRoute], epClass: typing.Any = None):
         self._routes = routes
         self._epClass = epClass or self.DEFAULT_ENDPOINT
@@ -165,10 +171,3 @@ class WebSocketRouter:
         """
         return self._epClass(*arg, routes=self.routes, **kw)
 
-    @property
-    def jspath(self):
-        """
-        Return the JavaScript path for use with Starlette Mount commands
-        """
-        return Path(__file__).parent/'static'
-
